@@ -4,13 +4,12 @@ from typing import Any, List
 
 
 class QueueListenerHandler(QueueHandler):
-    """
-    Configures queue listener and handler to support non-blocking logging configuration.
-    """
+    """Configures queue listener and handler to support non-blocking logging
+    configuration."""
 
     def __init__(self, handlers: List[Any], respect_handler_level: bool = False, queue: Queue = Queue(-1)):
-        """
-        Configures queue listener and handler to support non-blocking logging configuration.
+        """Configures queue listener and handler to support non-blocking
+        logging configuration.
 
         Args:
             handlers (list): list of handler names.
@@ -26,8 +25,8 @@ class QueueListenerHandler(QueueHandler):
 
 
 def resolve_handlers(handlers: List[Any]) -> List[Any]:
-    """
-    Converts list of string of handlers to the object of respective handler.
+    """Converts list of string of handlers to the object of respective handler.
+
     Indexing the list performs the evaluation of the object.
     """
     return [handlers[i] for i in range(len(handlers))]
